# Credits

## Main Developer

* Veronica Berglyd Olsen

## Contributors

* Early Concept: Marian Lückhof
* Internationalisation: Bruno Meneguello
* Setup and Packaging: Rachel Powers

For other contributions, see the project's [Contributors](https://github.com/vkbo/novelWriter/graphs/contributors) page.

## Artwork

The artwork on the Welcome dialog was created by Louis Durrant.

## Translations

The default language is English (UK) with English (US) as an option. These are the original
translators for the languages currently available:

* **Czech:** Tomáš Zmek (perteus)
* **Dutch:** Martijn van der Kleijn (mvdkleijn)
* **French:** Jan Lüdke (jyhelle)
* **German:** Myian (HeyMyian)
* **Italian:** Riccardo Mangili
* **Japanese:** hebekeg
* **Latin American Spanish:** Tommy Marplatt (tmarplatt)
* **Norwegian:** Veronica Berglyd Olsen (vkbo)
* **Polish:** Anna Maria Polak (Nauthiz)
* **Portuguese:** Bruno Meneguello (bkmeneguello)
* **Russian:** Konstantin Tan (k1kimosha)
* **Simplified Chinese:** Qianzhi Long (longqzh)

Additional larger translation contributions:

* **French:** Albert Aribaud (aaribaud)
* **Portuguese:** Oli Maia (olimaia)

Translations are managed on [Crowdin](https://crowdin.com/project/novelwriter), and more
contributions are listed on the project's Members page.

## Libraries

The following libraries are dependencies of novelWriter:

* **Qt5** by Qt Company
* **PyQt5** by Riverbank Computing
* **Enchant** by Dom Lachowicz
* **PyEnchant** by Dimitri Merejkowsky

## Assets

Some of the assets bundled with novelWriter were adapted from the following sources:

* **Typicons** icons by Stephen Hutchings (CC BY-SA 4.0)
* **Tomorrow** syntax themes by Chris Kempson (MIT License)
* **Owl** syntax themes by Sarah Drasner (MIT License)
* **Solarized** themes by Ethan Schoonover (MIT License)
* **Cyberpunk Night** theme by Anders Lemvigh (CC BY-SA 4.0)
* **Dracula** theme by Zeno Rocha (MIT License)
* **Snazzy Light** theme by Florian Reuschel (MIT License)

## Fonts

The font used for the main novelWriter logo, mimetype and text banners is Pridi. Other fonts are
used on buttons and icons.

* **Pridi** by Cadson Demak (Open Font License, Version 1.1)
* **Source Sans Pro** by Paul D. Hunt (SIL Open Font License)

## Special Mentions

Additional thanks to John Blommers who was an early user and who has provided a lot of very useful
feedback over the years.
